@@ -122,6 +122,12 @@ static LONG WINAPI windowsExceptionHandler(PEXCEPTION_POINTERS pExceptionInfo)
 # include <sys/stat.h>
 # include <sys/wait.h>
 # include <sys/utsname.h>
+#ifdef WZ_OS_LINUX
+# include <sys/prctl.h>
+#ifndef PR_SET_PTRACER
+# define PR_SET_PTRACER 0x59616d61  // prctl will ignore unknown options
+#endif
+#endif
 
 // GNU extension for backtrace():
 # if defined(__GLIBC__)
@@ -129,6 +135,7 @@ static LONG WINAPI windowsExceptionHandler(PEXCEPTION_POINTERS pExceptionInfo)
 #  define MAX_BACKTRACE 20
 # endif
 
+#define write(x, y, z) abs(write(x, y, z))  // HACK Squelch unused result warning.
 
 # define MAX_PID_STRING 16
 # define MAX_DATE_STRING 256
@@ -487,6 +494,11 @@ static pid_t execGdb(int const dumpFile, int* gdbWritePipe)
 	// Check to see if we're the parent
 	if (pid != 0)
 	{
+#ifdef WZ_OS_LINUX
+		// Allow tracing the process, some hardened kernel configurations disallow this.
+		prctl(PR_SET_PTRACER, pid, 0, 0, 0);
+#endif
+
 		// Return the write end of the pipe
 		*gdbWritePipe = gdbPipe[1];
 
