@@ -121,7 +121,7 @@ static const struct
 	{ "pl", LANG_NAME_POLISH, LANG_POLISH, SUBLANG_DEFAULT },
 	{ "pt_BR", LANG_NAME_PORTUGUESE_BRAZILIAN, LANG_PORTUGUESE, SUBLANG_PORTUGUESE_BRAZILIAN },
 	{ "pt", LANG_NAME_PORTUGUESE, LANG_PORTUGUESE, SUBLANG_DEFAULT },
-//	{ "ro", LANG_NAME_ROMANIAN, LANG_ROMANIAN, SUBLANG_DEFAULT },
+	{ "ro", LANG_NAME_ROMANIAN, LANG_ROMANIAN, SUBLANG_DEFAULT },
 	{ "ru", LANG_NAME_RUSSIAN, LANG_RUSSIAN, SUBLANG_DEFAULT },
 	{ "sk", LANG_NAME_SLOVAK, LANG_SLOVAK, SUBLANG_DEFAULT },
 	{ "sl", LANG_NAME_SLOVENIAN, LANG_SLOVENIAN, SUBLANG_DEFAULT },
@@ -131,7 +131,7 @@ static const struct
 //	{ "sv_SE", LANG_NAME_SWEDISH_SWEDEN, LANG_SWEDISH, SUBLANG_SWEDISH },
 #endif
 //	{ "sv", LANG_NAME_SWEDISH, LANG_SWEDISH, SUBLANG_DEFAULT },
-//	{ "tr", LANG_NAME_TURKISH, LANG_TURKISH, SUBLANG_DEFAULT },
+	{ "tr", LANG_NAME_TURKISH, LANG_TURKISH, SUBLANG_DEFAULT },
 //	{ "uz", LANG_NAME_UZBEK_CYRILLIC, LANG_UZBEK, SUBLANG_UZBEK_CYRILLIC },
 	{ "uk_UA", LANG_NAME_UKRAINIAN, LANG_UKRAINIAN, SUBLANG_DEFAULT },
 //	{ "zh_CN", LANG_NAME_CHINESE_SIMPLIFIED, LANG_CHINESE, SUBLANG_CHINESE_SIMPLIFIED },
@@ -179,13 +179,13 @@ static const struct
 	{ "pl", LANG_NAME_POLISH, "pl.UTF-8", "pl" },
 	{ "pt_BR", LANG_NAME_PORTUGUESE_BRAZILIAN, "pt_BR.UTF-8", "pt_BR" },
 	{ "pt", LANG_NAME_PORTUGUESE, "pt_PT.UTF-8", "pt_PT" },
-//	{ "ro", LANG_NAME_ROMANIAN, "ro.UTF-8", "ro" },
+	{ "ro", LANG_NAME_ROMANIAN, "ro.UTF-8", "ro" },
 	{ "ru", LANG_NAME_RUSSIAN, "ru_RU.UTF-8", "ru_RU" },
 	{ "sk", LANG_NAME_SLOVAK, "sk_SK.UTF-8", "sk_SK" },
 	{ "sl", LANG_NAME_SLOVENIAN, "sl.UTF-8", "sl" },
 //	{ "sv_SE", LANG_NAME_SWEDISH_SWEDEN, "sv_SE.UTF-8", "sv_SE" },
 //	{ "sv", LANG_NAME_SWEDISH, "sv.UTF-8", "sv" },
-//	{ "tr", LANG_NAME_TURKISH, "tr.UTF-8", "tr" },
+	{ "tr", LANG_NAME_TURKISH, "tr_TR.UTF-8", "tr_TR" },
 //	{ "uz", LANG_NAME_UZBEK_CYRILLIC, "uz.UTF-8", "uz" },
 	{ "uk_UA", LANG_NAME_UKRAINIAN, "uk_UA.UTF-8", "uk_UA" },
 //	{ "zh_CN", LANG_NAME_CHINESE_SIMPLIFIED, "zh_CN.UTF-8", "zh_CN" },
@@ -406,6 +406,11 @@ void initI18n(void)
 			debug( LOG_ERROR, "Could not change to resources directory." );
 		}
 
+		if (resourceURL != NULL)
+		{
+			CFRelease(resourceURL);
+		}
+
 		debug(LOG_INFO, "resourcePath is %s", resourcePath);
 	}
 	#else
