@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -66,8 +66,16 @@
 #define WZCOL_MENU_SHADOW	psPalette[41]
 #define WZCOL_DBLUE					psPalette[42]
 #define WZCOL_LBLUE					psPalette[43]
+// 44-47 are only used in trunk
+#define WZCOL_HEALTH_HIGH_SHADOW	psPalette[47]
+#define WZCOL_HEALTH_MEDIUM_SHADOW	psPalette[48]
+#define WZCOL_HEALTH_LOW_SHADOW		psPalette[49]
+#define WZCOL_HEALTH_RESISTANCE		psPalette[50]
+#define WZCOL_BLUEPRINT_VALID		psPalette[51]
+#define WZCOL_BLUEPRINT_INVALID		psPalette[52]
+#define WZCOL_BLUEPRINT_PLANNED		psPalette[53]
 
-#define WZCOL_MAX			44
+#define WZCOL_MAX			54
 
 //*************************************************************************
 
@@ -102,4 +110,17 @@ static inline PIELIGHT pal_SetBrightness(UBYTE brightness)
 	return c;
 }
 
+#define pal_Grey pal_SetBrightness
+
+static inline PIELIGHT pal_RGBA(UBYTE r, UBYTE g, UBYTE b, UBYTE a)
+{
+	PIELIGHT c;
+
+	c.byte.r = r;
+	c.byte.g = g;
+	c.byte.b = b;
+	c.byte.a = a;
+
+	return c;
+}
 #endif
