@@ -122,6 +122,7 @@ typedef enum
 	NET_FILE_REQUESTED,		//71 Player has requested a file (map/mod/?)
 	NET_FILE_CANCELLED,		//72 Player cancelled a file request
 	NET_FILE_PAYLOAD,		//73 sending file to the player that needs it
+	NET_ARTIFACTS_REQUEST,	//74
 	NUM_GAME_PACKETS		//   *MUST* be last.
 } MESSAGE_TYPES;
 #define SYNC_FLAG (NUM_GAME_PACKETS * NUM_GAME_PACKETS)	//special flag used for logging.
@@ -131,7 +132,9 @@ typedef enum
 #define MaxMsgSize		16384		// max size of a message in bytes.
 #define	StringSize		64			// size of strings used.
 #define MaxGames		12			// max number of concurrently playable games to allow.
-#define extra_string_size	239		// extra 255 char for future use
+#define extra_string_size	159		// extra 199 char for future use
+#define map_string_size		40
+#define	hostname_string_size	40
 #define modlist_string_size	255		// For a concatenated list of mods
 #define password_string_size 64		// longer passwords slow down the join code
 
@@ -163,6 +166,8 @@ typedef struct
 	// NOTE: do NOT save the following items in game.c--it will break savegames.
 	char		secondaryHosts[2][40];
 	char		extra[extra_string_size];		// extra string (future use)
+	char		mapname[map_string_size];		// map server is hosting
+	char		hostname[hostname_string_size];	// ...
 	char		versionstring[StringSize];		// 
 	char		modlist[modlist_string_size];	// ???
 	uint32_t	game_version_major;				// 
@@ -346,8 +351,8 @@ extern unsigned int NETgetGameserverPort(void);
 
 extern BOOL NETsetupTCPIP(const char *machine);
 extern void NETsetGamePassword(const char *password);
-extern void NETBroadcastPlayerInfo(uint32_t index);
-void NETBroadcastTwoPlayerInfo(uint32_t index1, uint32_t index2);
+extern void NETsendPlayerInfo(uint32_t index);
+extern void NETSendAllPlayerInfoTo(unsigned int to);
 extern bool NETisCorrectVersion(uint32_t game_version_major, uint32_t game_version_minor);
 extern bool NETgameIsCorrectVersion(GAMESTRUCT* check_game);
 void NET_InitPlayer(int i, bool initPosition);
@@ -355,5 +360,6 @@ extern void NET_InitPlayers(void);
 
 void NETGameLocked(bool flag);
 void NETresetGamePassword(void);
+void NET_TEST( int a, int b);
 
 #endif
