@@ -480,7 +480,6 @@ bool seq_Play(const char* filename)
 {
 	int pp_level_max = 0;
 	int pp_level = 0;
-	int pp_inc = 0;
 	ogg_packet op;
 
 	debug(LOG_VIDEO, "starting playback of: %s", filename);
@@ -497,7 +496,12 @@ bool seq_Play(const char* filename)
 	if (fpInfile == NULL)
 	{
 		info("unable to open '%s' for playback", filename);
-		return false;
+		
+		fpInfile = PHYSFS_openRead("novideo.ogg");
+		if (fpInfile == NULL)
+		{
+			return false;
+		}
 	}
 
 	theora_p = 0;
@@ -640,7 +644,6 @@ bool seq_Play(const char* filename)
 		theora_control(&videodata.td, TH_DECCTL_GET_PPLEVEL_MAX, &pp_level_max, sizeof(pp_level_max));
 		pp_level = pp_level_max;
 		theora_control(&videodata.td, TH_DECCTL_SET_PPLEVEL, &pp_level, sizeof(pp_level));
-		pp_inc = 0;
 	}
 	else
 	{
