@@ -367,17 +367,13 @@ static AUDIO_SAMPLE *audio_QueueSample( SDWORD iTrack )
 //
 void audio_QueueTrack( SDWORD iTrack )
 {
-	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-	AUDIO_SAMPLE	*psSample = NULL;
-	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
 	// return if audio not enabled
 	if ( g_bAudioEnabled == false || g_bAudioPaused == true)
 	{
 		return;
 	}
 
-	psSample = audio_QueueSample( iTrack );
+	audio_QueueSample( iTrack );
 }
 
 //*
@@ -700,7 +696,7 @@ static BOOL audio_Play3DTrack( SDWORD iX, SDWORD iY, SDWORD iZ, int iTrack, void
 	// coordinates
 	float	listenerX = .0f, listenerY = .0f, listenerZ = .0f, dX, dY, dZ;
 	// calculation results
-	float	distance, gain, sfx3d_volume;
+	float	distance, gain;
 #ifndef WZ_NOSOUND
 	ALenum err;
 #endif
@@ -732,7 +728,6 @@ static BOOL audio_Play3DTrack( SDWORD iX, SDWORD iY, SDWORD iZ, int iTrack, void
 	dZ = (float)iZ - listenerZ;
 	distance = sqrtf(dX * dX + dY * dY + dZ * dZ); // Pythagorean theorem
 
-	sfx3d_volume = sound_GetEffectsVolume();
 	// compute gain
 	gain = (1.0 - (distance * ATTENUATION_FACTOR)) ;//* 1.0f * sfx3d_volume
 	if (gain > 1.0f)
