@@ -297,7 +297,6 @@ void buttonDisplay(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *p
 {
 	W_BUTTON	*psButton;
 	SDWORD		x0,y0,x1,y1, fx,fy,fw;
-	int			CurrFontID;
 
 	ASSERT(psWidget != NULL && pColours != NULL, "Invalid pointers");
 	if (!psWidget || !pColours)
@@ -306,7 +305,6 @@ void buttonDisplay(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *p
 	}
 
 	psButton = (W_BUTTON *)psWidget;
-	CurrFontID = psButton->FontID;
 
 	x0=psButton->x + xOffset;
 	y0=psButton->y + yOffset;
