@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,81 +23,52 @@
  * Data loading functions used by the framework resource module.
  *
  */
-#include <string.h>
-#include <ctype.h>
+
+#include <SDL.h>
 
 #include "lib/framework/frame.h"
-#include "lib/framework/strres.h"
-//render library
-#include "lib/ivis_common/piedef.h"
-#include "lib/ivis_common/piestate.h"
-#include "lib/ivis_common/bitimage.h"
-
-#include "texture.h"
-#include "warzoneconfig.h"
-#include "lib/ivis_common/tex.h"
-#include "lib/ivis_common/textdraw.h"
-
 #include "lib/framework/frameresource.h"
-#include "stats.h"
-#include "structure.h"
-#include "feature.h"
-#include "research.h"
-#include "data.h"
-#include "text.h"
-#include "droid.h"
-#include "function.h"
-#include "message.h"
-#include "lib/script/script.h"
-#include "scriptvals.h"
-#include "display3d.h"
-#include "game.h"
-#include "objects.h"
-#include "display.h"
-#include "lib/sound/audio.h"
-#include "lib/gamelib/anim.h"
+#include "lib/framework/strres.h"
 #include "lib/gamelib/parser.h"
-#include "levels.h"
-#include "mechanics.h"
-#include "display3d.h"
-#include "display3ddef.h"
-#include "init.h"
-#include "lib/ivis_common/png_util.h"
+#include "lib/ivis_common/bitimage.h"
+#include "lib/ivis_common/tex.h"
+#include "lib/script/script.h"
+#include "lib/sound/audio.h"
 
+#include "data.h"
+#include "droid.h"
+#include "feature.h"
+#include "function.h"
+#include "mechanics.h"
+#include "message.h"
 #include "multiplay.h"
-#include "lib/netplay/netplay.h"
-#include <SDL.h>
-/**********************************************************
- *
- * Local Variables
- *
- *********************************************************/
-void calcDataHash(uint8_t *pBuffer, uint32_t size, uint32_t index);
-UDWORD	hashBuffer(uint8_t *pData, uint32_t size);
+#include "research.h"
+#include "scriptvals.h"
+#include "stats.h"
+#include "text.h"
+#include "texture.h"
 
 // whether a save game is currently being loaded
-static BOOL saveFlag = false;
-
-extern int scr_lineno;
+static bool saveFlag = false;
 
 uint32_t	DataHash[DATA_MAXDATA]= {0};
 
 /**
 *	hashBuffer()
-*	\param pData pointer to our buffer
+*	\param pData pointer to our buffer (always a text file)
 *	\param size the size of the buffer
 *	\return hash calculated from the buffer.
 *
 *	Note, this is obviously not a very complex hash routine.  This most likely has many collisions possible.
-*	The conversion from CRLF | CR to LF is more complex. :P
 *	This is almost the same routine that Pumpkin had, minus the ugly bug :)
 */
-UDWORD	hashBuffer(uint8_t *pData, uint32_t size)
+static UDWORD	hashBuffer(uint8_t *pData, uint32_t size)
 {
 	uint32_t hashval = 0,*val;
 	uint32_t pt = 0, newsize, i;
 	int fillbytes = 0, CRtoStrip = 0;
 	uint8_t *NewData = NULL;
+	bool isWindowsFormat = false;
 
 	// find out how many CRs are in the buffer
 	for (i=0; i < size; i++)
@@ -108,6 +79,7 @@ UDWORD	hashBuffer(uint8_t *pData, uint32_t size)
 		}
 	}
 
+	// Calculate the new size of the buffer we need to create, on a 4 byte boundry
 	fillbytes = (size - CRtoStrip) % 4;
 	if (fillbytes == 0)
 	{
@@ -117,64 +89,70 @@ UDWORD	hashBuffer(uint8_t *pData, uint32_t size)
 	{
 		newsize = (size - CRtoStrip) + (4- fillbytes);
 		fillbytes = newsize % 4;
-		debug(LOG_NET, "The size of the buffer (%u bytes) is not on a 4 byte boundry, compensating to a new buffer size of %u bytes.", size, newsize);
 	}
 
 	NewData = malloc(newsize * sizeof(uint8_t));
 	if (!NewData)
 	{
-		//fatal error...
-		debug(LOG_ERROR, "Out of memory!");
-		exit(-1);
+		debug(LOG_FATAL, "Out of memory!");
+		abort();
 	}
-	memset(NewData, 0xff, newsize);		// fill the new buffer with bit pattern 0xff
+	memset(NewData, 0xff, newsize);		// fill the new buffer with bit pattern 0xff for easier debug purposes
 
-	// convert CRLF (windows) | CR (mac OS9?) to LF
+	// convert CRLF (windows) to LF
 	for(i = 0; i < size- CRtoStrip; i++, pData++)
 	{
-		if (*(pData) == '\r' && *(pData+1) == '\n')
+		if (*pData == '\r' && *(pData + 1) == '\n')
 		{
-			NewData[i] = *(++pData);						// for windows change CRLF to LF
-		}
-		else if (*(pData) == '\r' && *(pData+1) != '\n')
-		{
-			NewData[i] = '\n';								// for mac change CR to LF
+			NewData[i] = *(++pData);			// for windows change CRLF to LF
+			isWindowsFormat = true;
 		}
 		else
 		{
-			NewData[i] = *(pData);							// straight copy
+			NewData[i] = *(pData);				// straight copy
 		}
 	}
 
 	debug(LOG_NEVER, "NewData is {%.10s}\n size is %u bytes \n", NewData, newsize );	// this is a bit spammy...
 
-	while (pt < newsize )
+	ASSERT_OR_RETURN(0, newsize != 0, "Empty file being checked!");
+	while (pt < newsize)
 	{
 		val = (uint32_t *)(NewData+pt);
-		hashval = SDL_SwapBE32(hashval ^ SDL_SwapBE32((*val)));		// I hope this is correct...can't test since no PPC machine
+
+		hashval ^= (*val);
+
 		// spams a ton--but useful for debugging.
 		//	debug(LOG_NET, "hash %08x pt %08x val is %08x", hashval, pt, *val);
 		pt += 4;
 	}
 
-	if (fillbytes)
-	{
-		free(NewData);
-	}
+	free(NewData);
 
+	debug(LOG_NET, "The size of the old buffer (%u bytes - %d stripped ), New buffer size of %u bytes. Format is: %s", size, CRtoStrip, newsize,  isWindowsFormat ? "windows" : "linux/mac");
 	return hashval;
 }
 
-void calcDataHash(uint8_t *pBuffer, uint32_t size, uint32_t index)
+// create the hash for that data block.
+// Data should be converted to Network byte order
+static void calcDataHash(uint8_t *pBuffer, uint32_t size, uint32_t index)
 {
+	const uint32_t oldHash = DataHash[index];
+
 	if (!bMultiPlayer)
 	{
 		return;
 	}
 
-	// create the hash for that data block.
-	DataHash[index] = SDL_SwapBE32(DataHash[index] ^ hashBuffer(pBuffer, size));	// check endian issues?
-	debug(LOG_NET, "DataHash[%2u] = %08x\n", index, DataHash[index]); 
+	DataHash[index] ^= SDL_SwapBE32(hashBuffer(pBuffer, size));
+
+	if (!DataHash[index] && oldHash)
+	{
+		debug(LOG_NET, "The new hash is 0, the old hash was %u. We XOR'ed the same value!", oldHash);
+	}
+
+	debug(LOG_NET, "DataHash[%2u] = %08x", index, SDL_SwapBE32(DataHash[index])); 
+
 	return;
 }
 
@@ -185,6 +163,7 @@ void resetDataHash(void)
 	{
 		DataHash[i] = 0;
 	}
+	debug(LOG_NET, "== Hash is reset ==");
 }
 
 /**********************************************************/
@@ -200,7 +179,7 @@ void dataClearSaveFlag(void)
 }
 
 /* Load the body stats */
-static BOOL bufferSBODYLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSBODYLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SBODY);
 
@@ -223,7 +202,7 @@ static void dataReleaseStats(WZ_DECL_UNUSED void *pData)
 
 
 /* Load the weapon stats */
-static BOOL bufferSWEAPONLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSWEAPONLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SWEAPON);
 
@@ -239,7 +218,7 @@ static BOOL bufferSWEAPONLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the constructor stats */
-static BOOL bufferSCONSTRLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSCONSTRLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SCONSTR);
 
@@ -255,7 +234,7 @@ static BOOL bufferSCONSTRLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the ECM stats */
-static BOOL bufferSECMLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSECMLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SECM);
 
@@ -271,7 +250,7 @@ static BOOL bufferSECMLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Propulsion stats */
-static BOOL bufferSPROPLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSPROPLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SPROP);
 
@@ -287,7 +266,7 @@ static BOOL bufferSPROPLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Sensor stats */
-static BOOL bufferSSENSORLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSSENSORLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SSENSOR);
 
@@ -303,7 +282,7 @@ static BOOL bufferSSENSORLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Repair stats */
-static BOOL bufferSREPAIRLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSREPAIRLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SREPAIR);
 
@@ -319,7 +298,7 @@ static BOOL bufferSREPAIRLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Brain stats */
-static BOOL bufferSBRAINLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSBRAINLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SBRAIN);
 
@@ -335,7 +314,7 @@ static BOOL bufferSBRAINLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the PropulsionType stats */
-static BOOL bufferSPROPTYPESLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSPROPTYPESLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SPROPTY);
 
@@ -351,7 +330,7 @@ static BOOL bufferSPROPTYPESLoad(const char *pBuffer, UDWORD size, void **ppData
 }
 
 /* Load the propulsion type sound stats */
-static BOOL bufferSPROPSNDLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSPROPSNDLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	if (!loadPropulsionSounds(pBuffer, size))
 	{
@@ -364,7 +343,7 @@ static BOOL bufferSPROPSNDLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the SSPECABIL stats */
-static BOOL bufferSSPECABILLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSSPECABILLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	if (!loadSpecialAbility(pBuffer, size))
 	{
@@ -377,7 +356,7 @@ static BOOL bufferSSPECABILLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the STERRTABLE stats */
-static BOOL bufferSTERRTABLELoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSTERRTABLELoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_STERRT);
 
@@ -392,7 +371,7 @@ static BOOL bufferSTERRTABLELoad(const char *pBuffer, UDWORD size, void **ppData
 }
 
 /* Load the body/propulsion IMDs stats */
-static BOOL bufferSBPIMDLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSBPIMDLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	if (!loadBodyPropulsionIMDs(pBuffer, size))
 	{
@@ -405,7 +384,7 @@ static BOOL bufferSBPIMDLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the weapon sound stats */
-static BOOL bufferSWEAPSNDLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSWEAPSNDLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	if (!loadWeaponSounds(pBuffer, size))
 	{
@@ -418,7 +397,7 @@ static BOOL bufferSWEAPSNDLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Weapon Effect modifier stats */
-static BOOL bufferSWEAPMODLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSWEAPMODLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SWEAPMOD);
 
@@ -434,7 +413,7 @@ static BOOL bufferSWEAPMODLoad(const char *pBuffer, UDWORD size, void **ppData)
 
 
 /* Load the Template stats */
-static BOOL bufferSTEMPLLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSTEMPLLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_STEMP);
 
@@ -456,7 +435,7 @@ static void dataSTEMPLRelease(WZ_DECL_UNUSED void *pData)
 }
 
 /* Load the Template weapons stats */
-static BOOL bufferSTEMPWEAPLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSTEMPWEAPLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_STEMPWEAP);
 
@@ -471,7 +450,7 @@ static BOOL bufferSTEMPWEAPLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Structure stats */
-static BOOL bufferSSTRUCTLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSSTRUCTLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SSTRUCT);
 
@@ -494,7 +473,7 @@ static void dataSSTRUCTRelease(WZ_DECL_UNUSED void *pData)
 }
 
 /* Load the Structure Weapons stats */
-static BOOL bufferSSTRWEAPLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSSTRWEAPLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SSTRWEAP);
 
@@ -509,7 +488,7 @@ static BOOL bufferSSTRWEAPLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Structure Functions stats */
-static BOOL bufferSSTRFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSSTRFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_STRFUNC);
 
@@ -524,7 +503,7 @@ static BOOL bufferSSTRFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Structure strength modifier stats */
-static BOOL bufferSSTRMODLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSSTRMODLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SSTRMOD);
 
@@ -539,7 +518,7 @@ static BOOL bufferSSTRMODLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the Feature stats */
-static BOOL bufferSFEATLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSFEATLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SFEAT);
 
@@ -560,7 +539,7 @@ static void dataSFEATRelease(WZ_DECL_UNUSED void *pData)
 }
 
 /* Load the Functions stats */
-static BOOL bufferSFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SFUNC);
 
@@ -591,7 +570,7 @@ static void dataRESCHRelease(WZ_DECL_UNUSED void *pData)
 }
 
 /* Load the Research stats */
-static BOOL bufferRESCHLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRESCHLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RESCH);
 
@@ -617,7 +596,7 @@ static BOOL bufferRESCHLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the research pre-requisites */
-static BOOL bufferRPREREQLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRPREREQLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RPREREQ);
 
@@ -632,7 +611,7 @@ static BOOL bufferRPREREQLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the research components made redundant */
-static BOOL bufferRCOMPREDLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRCOMPREDLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RCOMPRED);
 
@@ -647,7 +626,7 @@ static BOOL bufferRCOMPREDLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the research component results */
-static BOOL bufferRCOMPRESLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRCOMPRESLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RCOMPRES);
 
@@ -662,7 +641,7 @@ static BOOL bufferRCOMPRESLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the research structures required */
-static BOOL bufferRSTRREQLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRSTRREQLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RSTRREQ);
 
@@ -677,7 +656,7 @@ static BOOL bufferRSTRREQLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the research structures made redundant */
-static BOOL bufferRSTRREDLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRSTRREDLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RSTRRED);
 
@@ -692,7 +671,7 @@ static BOOL bufferRSTRREDLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the research structure results */
-static BOOL bufferRSTRRESLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRSTRRESLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RSTRRES);
 
@@ -707,7 +686,7 @@ static BOOL bufferRSTRRESLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the research functions */
-static BOOL bufferRFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferRFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	calcDataHash((uint8_t *)pBuffer, size, DATA_RFUNC);
 
@@ -722,7 +701,7 @@ static BOOL bufferRFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load the message viewdata */
-static BOOL bufferSMSGLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool bufferSMSGLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	VIEWDATA	*pViewData;
 
@@ -738,7 +717,7 @@ static BOOL bufferSMSGLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load research message viewdata */
-static BOOL dataResearchMsgLoad(const char* fileName, void** ppData)
+static bool dataResearchMsgLoad(const char* fileName, void** ppData)
 {
 	VIEWDATA* pViewData = loadResearchViewData(fileName);
 	if (!pViewData)
@@ -758,7 +737,7 @@ static void dataSMSGRelease(void *pData)
 }
 
 /* Load an imd */
-static BOOL dataIMDBufferLoad(const char *pBuffer, UDWORD size, void **ppData)
+static bool dataIMDBufferLoad(const char *pBuffer, UDWORD size, void **ppData)
 {
 	iIMDShape	*psIMD;
 	const char *pBufferPosition = pBuffer;
@@ -777,7 +756,7 @@ static BOOL dataIMDBufferLoad(const char *pBuffer, UDWORD size, void **ppData)
 /*!
  * Load an image from file
  */
-static BOOL dataImageLoad(const char *fileName, void **ppData)
+static bool dataImageLoad(const char *fileName, void **ppData)
 {
 	iV_Image *psSprite = malloc(sizeof(iV_Image));
 	if (!psSprite)
@@ -798,7 +777,7 @@ static BOOL dataImageLoad(const char *fileName, void **ppData)
 
 
 // Tertiles (terrain tiles) loader.
-static BOOL dataTERTILESLoad(const char *fileName, void **ppData)
+static bool dataTERTILESLoad(const char *fileName, void **ppData)
 {
 	bool status;
 
@@ -816,7 +795,7 @@ static void dataTERTILESRelease(WZ_DECL_UNUSED void *pData)
 }
 
 
-static BOOL dataIMGLoad(const char *fileName, void **ppData)
+static bool dataIMGLoad(const char *fileName, void **ppData)
 {
 	*ppData = iV_LoadImageFile(fileName);
 	if(*ppData == NULL)
@@ -835,7 +814,7 @@ static void dataIMGRelease(void *pData)
 
 
 /* Load a texturepage into memory */
-static BOOL dataTexPageLoad(const char *fileName, void **ppData)
+static bool dataTexPageLoad(const char *fileName, void **ppData)
 {
 	char texpage[PATH_MAX] = {'\0'};
 
@@ -880,7 +859,7 @@ static void dataImageRelease(void *pData)
 
 
 /* Load an audio file */
-static BOOL dataAudioLoad(const char* fileName, void **ppData)
+static bool dataAudioLoad(const char* fileName, void **ppData)
 {
 	if ( audio_Disabled() == true )
 	{
@@ -896,9 +875,9 @@ static BOOL dataAudioLoad(const char* fileName, void **ppData)
 }
 
 /* Load an audio file */
-static BOOL dataAudioCfgLoad(const char* fileName, void **ppData)
+static bool dataAudioCfgLoad(const char* fileName, void **ppData)
 {
-	BOOL success;
+	bool success;
 	PHYSFS_file* fileHandle;
 
 	*ppData = NULL;
@@ -923,7 +902,7 @@ static BOOL dataAudioCfgLoad(const char* fileName, void **ppData)
 }
 
 /* Load an anim file */
-static BOOL dataAnimLoad(const char *fileName, void **ppData)
+static bool dataAnimLoad(const char *fileName, void **ppData)
 {
 	PHYSFS_file* fileHandle = PHYSFS_openRead(fileName);
 	debug(LOG_WZ, "Reading...[directory: %s] %s", PHYSFS_getRealDir(fileName), fileName);
@@ -941,9 +920,9 @@ static BOOL dataAnimLoad(const char *fileName, void **ppData)
 }
 
 /* Load an audio config file */
-static BOOL dataAnimCfgLoad(const char *fileName, void **ppData)
+static bool dataAnimCfgLoad(const char *fileName, void **ppData)
 {
-	BOOL success;
+	bool success;
 	PHYSFS_file* fileHandle = PHYSFS_openRead(fileName);
 	*ppData = NULL;
 
@@ -967,7 +946,7 @@ static void dataAnimRelease( void *pData )
 }
 
 /* Load a string resource file */
-static BOOL dataStrResLoad(const char* fileName, void** ppData)
+static bool dataStrResLoad(const char* fileName, void** ppData)
 {
 	// recreate the string resource if it was freed by a WRF release
 	if (psStringRes == NULL)
@@ -999,7 +978,7 @@ static void dataStrResRelease(WZ_DECL_UNUSED void *pData)
 
 /* Load a script file */
 // All scripts, binary or otherwise are now passed through this routine
-static BOOL dataScriptLoad(const char* fileName, void **ppData)
+static bool dataScriptLoad(const char* fileName, void **ppData)
 {
 	static const bool printHack = false;
 	SCRIPT_CODE** psProg = (SCRIPT_CODE**)ppData;
@@ -1008,7 +987,6 @@ static BOOL dataScriptLoad(const char* fileName, void **ppData)
 	PHYSFS_sint64 fileSize = 0;
 
 	debug(LOG_WZ, "COMPILING SCRIPT ...%s", GetLastResourceFilename());
-	scr_lineno = 1;
 
 	fileHandle = PHYSFS_openRead(fileName);
 	debug(LOG_WZ, "Reading...[directory: %s] %s", PHYSFS_getRealDir(fileName), fileName);
@@ -1022,7 +1000,7 @@ static BOOL dataScriptLoad(const char* fileName, void **ppData)
 	pBuffer = malloc(fileSize * sizeof(char));
 	if (pBuffer == NULL)
 	{
-		debug(LOG_ERROR, "Fatal memory allocation, couldn't allocate %lld buffer", fileSize);
+		debug(LOG_FATAL, "Fatal memory allocation, couldn't allocate %lld buffer", fileSize);
 		abort();
 	}
 
@@ -1060,9 +1038,9 @@ static void dataScriptRelease(void *pData)
 
 
 // Load a script variable values file
-static BOOL dataScriptLoadVals(const char* fileName, void **ppData)
+static bool dataScriptLoadVals(const char* fileName, void **ppData)
 {
-	BOOL success;
+	bool success;
 	PHYSFS_file* fileHandle;
 	uint8_t *pBuffer;
 	PHYSFS_sint64 fileSize = 0;
@@ -1089,7 +1067,7 @@ static BOOL dataScriptLoadVals(const char* fileName, void **ppData)
 	pBuffer = malloc(fileSize * sizeof(char));
 	if (pBuffer == NULL)
 	{
-		debug(LOG_ERROR, "Fatal memory allocation, couldn't allocate %lld buffer", fileSize);
+		debug(LOG_FATAL, "Fatal memory allocation, couldn't allocate %lld buffer", fileSize);
 		abort();
 	}
 
@@ -1104,7 +1082,7 @@ static BOOL dataScriptLoadVals(const char* fileName, void **ppData)
 	success = scrvLoad(fileHandle);
 
 	if (!success)
-		debug(LOG_ERROR, "Script %s did not compile", GetLastResourceFilename());
+		debug(LOG_FATAL, "Script %s did not compile", GetLastResourceFilename());
 
 	PHYSFS_close(fileHandle);
 
@@ -1183,7 +1161,7 @@ static const RES_TYPE_MIN_FILE FileResourceTypes[] =
 };
 
 /* Pass all the data loading functions to the framework library */
-BOOL dataInitLoadFuncs(void)
+bool dataInitLoadFuncs(void)
 {
 	// init the data integrity hash;
 	resetDataHash();
