@@ -392,6 +392,16 @@ void ProcessRadarInput(void)
 
 			if (mousePressed(MOUSE_ORDER) || (mousePressed(MOUSE_MMB) && keyDown(KEY_LALT)))
 			{
+				if (mousePressed(MOUSE_ORDER))
+				{
+					x = mousePressPos(MOUSE_ORDER).x;
+					y = mousePressPos(MOUSE_ORDER).y;
+				}
+				else
+				{
+					x = mousePressPos(MOUSE_MMB).x;
+					y = mousePressPos(MOUSE_MMB).y;
+				}
 				if(driveModeActive()) {
 					driveProcessRadarInput(x,y);
 				} else {
@@ -431,6 +441,9 @@ void ProcessRadarInput(void)
 			}
 			else if (mousePressed(MOUSE_SELECT))
 			{
+				x = mousePressPos(MOUSE_SELECT).x;
+				y = mousePressPos(MOUSE_SELECT).y;
+
 				CalcRadarPosition(x, y, &PosX, &PosY);
 
 				if(bInstantRadarJump)
@@ -464,6 +477,11 @@ void processInput(void)
 	BOOL mOverRadar = false;
 	int WheelZoomIterator;
 
+	if (InGameOpUp || isInGamePopupUp)
+	{
+		dragBox3D.status = DRAG_RELEASED;	// disengage the dragging since it stops menu input
+	}
+
 	if(radarOnScreen && getHQExists(selectedPlayer) && CoordInRadar(mouseX(), mouseY()))
 	{
 		mOverRadar = true;
@@ -1646,7 +1664,6 @@ void dealWithDroidSelect(DROID *psDroid, BOOL bDragBox)
 {
 	DROID	*psD;
 	BOOL	bGotGroup;
-	SDWORD	groupNumber = 0;
 
 	/*	Toggle selection on and off - allows you drag around a big
 		area of droids and then exclude certain individuals */
@@ -1671,7 +1688,6 @@ void dealWithDroidSelect(DROID *psDroid, BOOL bDragBox)
 			if(psD->selected && (psD->group!=UBYTE_MAX))
 			{
 				bGotGroup = true;
-				groupNumber = psD->group;
 			}
 		}
 //		psDroid->selected = true;
@@ -2199,7 +2215,7 @@ static void dealWithLMBObject(BASE_OBJECT* psClickedOn)
 
 		default:
 			// assert only when the value is outside of the valid range
-			ASSERT((type >= 0 && type < OBJ_NUM_TYPES), "Weird selection from LMB - type of clicked object is %d", (int)type);
+			ASSERT(type < OBJ_NUM_TYPES, "Weird selection from LMB - type of clicked object is %d", (int)type);
 			break;
 	}
 }
