@@ -157,7 +157,7 @@ BOOL loadFeatureStats(const char *pFeatureData, UDWORD bufferSize)
 
 
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pFeatureData, "%[^','],%d,%d,%d,%d,%d,%[^','],%[^','],%d,%d,%d",
+		sscanf(pFeatureData, "%255[^,'\r\n],%d,%d,%d,%d,%d,%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d",
 			featureName, &Width, &Breadth,
 			&damageable, &psFeature->armourValue, &psFeature->body,
 			GfxFile, type, &tileDraw, &allowLOS,
@@ -261,7 +261,6 @@ FEATURE * buildFeature(FEATURE_STATS *psStats, UDWORD x, UDWORD y,BOOL FromSave)
 	UDWORD		width,breadth, foundationMin,foundationMax, height;
 	UDWORD		startX,startY,max,min;
 	SDWORD		i;
-	UBYTE		vis;
 
 	//try and create the Feature
 	FEATURE* psFeature = createFeature();
@@ -298,13 +297,22 @@ FEATURE * buildFeature(FEATURE_STATS *psStats, UDWORD x, UDWORD y,BOOL FromSave)
 	//return the average of max/min height
 	height = (foundationMin + foundationMax) / 2;
 
-	if(FromSave == true) {
-		psFeature->pos.x = (UWORD)x;
-		psFeature->pos.y = (UWORD)y;
-	} else {
-		psFeature->pos.x = (UWORD)((x & (~TILE_MASK)) + psStats->baseWidth * TILE_UNITS / 2);
-		psFeature->pos.y = (UWORD)((y & (~TILE_MASK)) + psStats->baseBreadth * TILE_UNITS / 2);
+	if (!FromSave)
+	{
+		x = (x & ~TILE_MASK) + psStats->baseWidth  %2 * TILE_UNITS/2;
+		y = (y & ~TILE_MASK) + psStats->baseBreadth%2 * TILE_UNITS/2;
 	}
+	else
+	{
+		if ((x & TILE_MASK) != psStats->baseWidth  %2 * TILE_UNITS/2 ||
+		    (y & TILE_MASK) != psStats->baseBreadth%2 * TILE_UNITS/2)
+		{
+			debug(LOG_NEVER, "Feature not aligned. position (%d,%d), size (%d,%d)", x, y, psStats->baseWidth, psStats->baseBreadth);
+		}
+	}
+
+	psFeature->pos.x = x;
+	psFeature->pos.y = y;
 
 	/* Dump down the building wrecks at random angles - still looks shit though */
 	if(psStats->subType == FEAT_BUILD_WRECK)
@@ -324,7 +332,8 @@ FEATURE * buildFeature(FEATURE_STATS *psStats, UDWORD x, UDWORD y,BOOL FromSave)
 	psFeature->psStats = psStats;
 	//psFeature->subType = psStats->subType;
 	psFeature->body = psStats->body;
-	psFeature->player = MAX_PLAYERS+1;	//set the player out of range to avoid targeting confusions
+	// NOTE: player = 9 is a feature!
+	psFeature->player = MAX_PLAYERS+1;	//set the player out of range to avoid targeting confusions 
 	psFeature->sensorRange = 0;
 	psFeature->sensorPower = 0;
 	psFeature->ECMMod = 0;
@@ -334,22 +343,6 @@ FEATURE * buildFeature(FEATURE_STATS *psStats, UDWORD x, UDWORD y,BOOL FromSave)
 	// it has never been drawn
 	psFeature->sDisplay.frameNumber = 0;
 
-	if(getRevealStatus())
-	{
-		vis = 0;
-	}
-	else
-	{
-		if(psStats->visibleAtStart)
-		{
-  			vis = UBYTE_MAX;
-		}
-		else
-		{
-			vis = 0;
-		}
-	}
-
 	// note that the advanced armour system current unused for features
 	for (i = 0; i < NUM_HIT_SIDES; i++)
 	{
@@ -367,13 +360,8 @@ FEATURE * buildFeature(FEATURE_STATS *psStats, UDWORD x, UDWORD y,BOOL FromSave)
 	}
 	//load into the map data
 
-	if(FromSave) {
-		mapX = map_coord(x) - psStats->baseWidth / 2;
-		mapY = map_coord(y) - psStats->baseBreadth / 2;
-	} else {
-		mapX = map_coord(x);
-		mapY = map_coord(y);
-	}
+	mapX = map_coord(x) - psStats->baseWidth / 2;
+	mapY = map_coord(y) - psStats->baseBreadth / 2;
 
 	// set up the imd for the feature
 	if(psFeature->psStats->subType==FEAT_BUILD_WRECK)
@@ -507,11 +495,11 @@ bool removeFeature(FEATURE *psDel)
 	}
 
 	//remove from the map data
-	mapX = map_coord(psDel->pos.x);
-	mapY = map_coord(psDel->pos.y);
-	for (width = -psDel->psStats->baseWidth; width < psDel->psStats->baseWidth; width++)
+	mapX = map_coord(psDel->pos.x) - psDel->psStats->baseWidth/2;
+	mapY = map_coord(psDel->pos.y) - psDel->psStats->baseBreadth/2;
+	for (width = 0; width < psDel->psStats->baseWidth; width++)
 	{
-		for (breadth = -psDel->psStats->baseBreadth; breadth < psDel->psStats->baseBreadth; breadth++)
+		for (breadth = 0; breadth < psDel->psStats->baseBreadth; breadth++)
 		{
 			if (tileOnMap(mapX + width, mapY + breadth))
 			{
@@ -612,8 +600,8 @@ bool destroyFeature(FEATURE *psDel)
 
 			// ----- Flip all the tiles under the skyscraper to a rubble tile
 			// smoke effect should disguise this happening
-			mapX = map_coord(psDel->pos.x - psDel->psStats->baseWidth * TILE_UNITS / 2);
-			mapY = map_coord(psDel->pos.y - psDel->psStats->baseBreadth * TILE_UNITS / 2);
+			mapX = map_coord(psDel->pos.x) - psDel->psStats->baseWidth/2;
+			mapY = map_coord(psDel->pos.y) - psDel->psStats->baseBreadth/2;
 //			if(psDel->sDisplay.imd->pos.ymax>300)
 			if (psDel->psStats->subType == FEAT_SKYSCRAPER)
 			{
