@@ -180,7 +180,7 @@ static BOOL loadProduction(const char *pData)
 	functionName[0] = '\0';
 	//propulsionType[0] = '\0';
 	bodySize[0] = '\0';
-	sscanf(pData, "%[^','],%[^','],%d", functionName, bodySize,
+	sscanf(pData, "%255[^,'\r\n],%255[^,'\r\n],%d", functionName, bodySize,
 		&productionOutput);
 
 	//allocate storage for the name
@@ -215,7 +215,7 @@ static BOOL loadProduction(const char *pData)
 	psFunction->propulsionType = propType;
 #endif
 
-	if (!getBodySize(bodySize, (UBYTE*)&psFunction->capacity))
+	if (!getBodySize(bodySize, &psFunction->capacity))
 	{
 
 		ASSERT( false, "loadProduction: unknown body size for %s",psFunction->pName );
@@ -268,7 +268,7 @@ static BOOL loadProductionUpgradeFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d,%d,%d,%d", functionName, &factory,
+	sscanf(pData, "%255[^,'\r\n],%d,%d,%d,%d", functionName, &factory,
 		&cyborg, &vtol,&outputModifier);
 
 
@@ -333,7 +333,7 @@ static BOOL loadResearchFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d", functionName, &psFunction->researchPoints);
+	sscanf(pData, "%255[^,'\r\n],%d", functionName, &psFunction->researchPoints);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -367,7 +367,7 @@ static BOOL loadReArmFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d", functionName, &psFunction->reArmPoints);
+	sscanf(pData, "%255[^,'\r\n],%d", functionName, &psFunction->reArmPoints);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -404,7 +404,7 @@ static BOOL loadUpgradeFunction(const char *pData, UBYTE type)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d", functionName, &modifier);
+	sscanf(pData, "%255[^,'\r\n],%d", functionName, &modifier);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -488,7 +488,7 @@ static BOOL loadDroidBodyUpgradeFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d,%d,%d,%d,%d,%d", functionName, &modifier,
+	sscanf(pData, "%255[^,'\r\n],%d,%d,%d,%d,%d,%d", functionName, &modifier,
 		&body, &armourKinetic,	&armourHeat, &droid, &cyborg);
 
 	//allocate storage for the name
@@ -555,7 +555,7 @@ static BOOL loadDroidSensorUpgradeFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d,%d", functionName, &modifier, &range);
+	sscanf(pData, "%255[^,'\r\n],%d,%d", functionName, &modifier, &range);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -605,7 +605,7 @@ static BOOL loadWeaponUpgradeFunction(const char *pData)
 	//read the data in
 	functionName[0] = '\0';
 	weaponSubClass[0] = '\0';
-	sscanf(pData, "%[^','],%[^','],%d,%d,%d,%d,%d,%d,%d", functionName,
+	sscanf(pData, "%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%d,%d", functionName,
 		weaponSubClass, &firePause, &shortHit, &longHit, &damage, &radiusDamage,
 		&incenDamage, &radiusHit);
 
@@ -674,7 +674,7 @@ static BOOL loadStructureUpgradeFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d,%d,%d", functionName, &armour, &body, &resistance);
+	sscanf(pData, "%255[^,'\r\n],%d,%d,%d", functionName, &armour, &body, &resistance);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -725,7 +725,7 @@ static BOOL loadWallDefenceUpgradeFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d,%d", functionName, &armour, &body);
+	sscanf(pData, "%255[^,'\r\n],%d,%d", functionName, &armour, &body);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -774,7 +774,7 @@ static BOOL loadPowerGenFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d,%d,%d,%d,%d,%d", functionName,
+	sscanf(pData, "%255[^,'\r\n],%d,%d,%d,%d,%d,%d", functionName,
 		&psFunction->powerOutput, &psFunction->powerMultiplier,
 		&psFunction->criticalMassChance, &psFunction->criticalMassRadius,
 		&psFunction->criticalMassDamage, &psFunction->radiationDecayTime);
@@ -819,7 +819,7 @@ static BOOL loadResourceFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d", functionName, &psFunction->maxPower);
+	sscanf(pData, "%255[^,'\r\n],%d", functionName, &psFunction->maxPower);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -855,7 +855,7 @@ static BOOL loadRepairDroidFunction(const char *pData)
 
 	//read the data in
 	functionName[0] = '\0';
-	sscanf(pData, "%[^','],%d", functionName,
+	sscanf(pData, "%255[^,'\r\n],%d", functionName,
 		&psFunction->repairPoints);
 
 	//allocate storage for the name
@@ -896,7 +896,7 @@ static BOOL loadWallFunction(const char *pData)
 	//read the data in
 	functionName[0] = '\0';
 	structureName[0] = '\0';
-	sscanf(pData, "%[^','],%[^','],%*d", functionName, structureName);
+	sscanf(pData, "%255[^,'\r\n],%255[^,'\r\n],%*d", functionName, structureName);
 
 	//allocate storage for the name
 	storeName((FUNCTION *)psFunction, functionName);
@@ -1586,7 +1586,7 @@ BOOL loadFunctionStats(const char *pFunctionData, UDWORD bufferSize)
 	{
 		//read the data into the storage - the data is delimeted using comma's
 		FunctionType[0] = '\0';
-		sscanf(pFunctionData, "%[^',']", FunctionType);
+		sscanf(pFunctionData, "%255[^,'\r\n]", FunctionType);
 		type = functionType(FunctionType);
 		pFunctionData += (strlen(FunctionType)+1);
 
