@@ -205,7 +205,7 @@ _keymapsave keyMapSaveTable[] =
 	kf_NormalSpeed,
 	kf_ToggleRadarJump,
 	kf_MovePause,
-	kf_ToggleReopenBuildMenu,
+	kf_NOOP,
 	kf_SensorDisplayOn,
 	kf_SensorDisplayOff,
 	kf_ToggleRadarTerrain,          //radar terrain on/off
@@ -431,7 +431,6 @@ void	keyInitMappings( BOOL bForceDefaults )
 	keyAddMapping(KEYMAP_ASSIGNABLE, KEY_IGNORE,(KEY_CODE)KEY_MAXSCAN, KEYMAP_PRESSED, kf_SelectNextResearch,      N_("Select next Research Facility"));
 	keyAddMapping(KEYMAP_ASSIGNABLE, KEY_IGNORE,(KEY_CODE)KEY_MAXSCAN, KEYMAP_PRESSED, kf_SelectNextPowerStation,  N_("Select next Power Generator"));
 	keyAddMapping(KEYMAP_ASSIGNABLE, KEY_IGNORE,(KEY_CODE)KEY_MAXSCAN, KEYMAP_PRESSED, kf_SelectNextCyborgFactory, N_("Select next Cyborg Factory"));
-	keyAddMapping(KEYMAP_ASSIGNABLE, KEY_IGNORE,(KEY_CODE)KEY_MAXSCAN, KEYMAP_PRESSED, kf_ToggleReopenBuildMenu,   N_("Toggle reopening the build menu"));
 
 	// NOTE THIS!!!!!!!
 	// available: ctrl+l
@@ -694,7 +693,6 @@ void	keyProcessMappings( BOOL bExclude )
 {
 KEY_MAPPING	*keyToProcess;
 BOOL		bMetaKeyDown;
-BOOL		bKeyProcessed;
 SDWORD		i;
 
 	/* Bomb out if there are none */
@@ -722,7 +720,6 @@ SDWORD		i;
  	for(keyToProcess = keyMappings; keyToProcess!=NULL; keyToProcess = keyToProcess->psNext)
 	{
 		/* We haven't acted upon it */
-		bKeyProcessed = false;
 		if(!keyToProcess->active)
 		{
 			/* Get out if it's inactive */
@@ -756,7 +753,6 @@ SDWORD		i;
  					lastSubKey = keyToProcess->subKeyCode;
  					/* Jump to the associated function call */
  					 keyToProcess->function();
-					 bKeyProcessed = true;
  				}
  				break;
  			case KEYMAP_DOWN:
@@ -766,7 +762,6 @@ SDWORD		i;
  					lastSubKey = keyToProcess->subKeyCode;
  					/* Jump to the associated function call */
  					 keyToProcess->function();
-					 bKeyProcessed = true;
  				}
 
  				break;
@@ -777,7 +772,6 @@ SDWORD		i;
  					lastSubKey = keyToProcess->subKeyCode;
  					/* Jump to the associated function call */
  					 keyToProcess->function();
-					 bKeyProcessed = true;
  				}
 				break;
 
@@ -797,7 +791,6 @@ SDWORD		i;
  				lastMetaKey = keyToProcess->metaKeyCode;
  				lastSubKey = keyToProcess->subKeyCode;
  				keyToProcess->function();
-				bKeyProcessed = true;
  			}
 			else if (keyToProcess->altMetaKeyCode != KEY_IGNORE)
 			{
@@ -806,7 +799,6 @@ SDWORD		i;
  					lastMetaKey = keyToProcess->metaKeyCode;
  					lastSubKey = keyToProcess->subKeyCode;
  					keyToProcess->function();
-					bKeyProcessed = true;
 				}
 			}
  		}
