@@ -321,6 +321,7 @@ static BOOL _addLoadSave(BOOL bLoad, const char *sSearchPath, const char *sExten
 		W_BUTTON *button;
 		char savefile[256];
 		time_t savetime;
+		struct tm *timeinfo;
 
 		// See if this filename contains the extension we're looking for
 		if (!strstr(*i, checkExtension))
@@ -336,7 +337,8 @@ static BOOL _addLoadSave(BOOL bLoad, const char *sSearchPath, const char *sExten
 		/* Figure save-time */
 		snprintf(savefile, sizeof(savefile), "%s/%s", sSearchPath, *i);
 		savetime = PHYSFS_getLastModTime(savefile);
-		sstrcpy(sSlotTips[slotCount], ctime(&savetime));
+		timeinfo = localtime(&savetime);
+		strftime(sSlotTips[slotCount], sizeof(sSlotTips[slotCount]), "%x %X", timeinfo);
 
 		/* Set the button-text */
 		(*i)[strlen(*i) - 4] = '\0'; // remove .gam extension
@@ -661,11 +663,12 @@ void removeWildcards(char *pStr)
 	{
 		pStr[MAX_SAVE_NAME - 1] = 0;
 	}
-	
+
 	// Trim trailing spaces
-	for (i=strlen(pStr)-1; pStr[i]==' ' && i>=0; i--);
-	pStr[i+1] = 0;
-	
+	for (i = strlen(pStr); i > 0 && pStr[i - 1] == ' '; --i)
+	{}
+	pStr[i] = 0;
+
 	// Trims leading spaces (currently unused)
 	/* for (i=0; pStr[i]==' '; i++);
 	if (i != 0)
