@@ -40,9 +40,11 @@ extern void addMultiPlayerRandomArtifacts	(uint8_t quantity, FEATURE_TYPE type);
 extern void processMultiPlayerArtifacts		(void);
 extern void recvMultiPlayerFeature(void);
 extern void sendMultiPlayerFeature(FEATURE_TYPE type, uint32_t x, uint32_t y, uint32_t id);
+extern void HandleArtifact(void);
 
 extern void	giftArtifact					(UDWORD owner,UDWORD x,UDWORD y);
-extern BOOL	addOilDrum						(uint8_t count);
+extern BOOL addOilDrum(uint8_t count);
+extern void requestOilDrum(uint8_t quantity);
 extern void	giftPower						(uint8_t from, uint8_t to, BOOL send);
 extern void giftRadar						(uint8_t from, uint8_t to, BOOL send);
 
