@@ -200,7 +200,7 @@ static void resetMultiVisibility(UDWORD player)
 // A remote player has left the game
 BOOL MultiPlayerLeave(UDWORD playerIndex)
 {
-	char	buf[255];
+	char	buf[255] = {'\0'};
 
 	if (playerIndex >= MAX_PLAYERS)
 	{
@@ -208,8 +208,9 @@ BOOL MultiPlayerLeave(UDWORD playerIndex)
 		return false;
 	}
 
-	NETlogEntry("Player leaving game", SYNC_FLAG, playerIndex);
-	debug(LOG_INFO,"** Player %u [%s], has left the game.", playerIndex, getPlayerName(playerIndex));
+	ssprintf(buf, "** Player %u [%s], has left the game.", playerIndex, getPlayerName(playerIndex));
+	NETlogEntry(buf, SYNC_FLAG, playerIndex);
+	debug(LOG_INFO,"%s", buf);
 
 	ssprintf(buf, _("%s has Left the Game"), getPlayerName(playerIndex));
 
@@ -319,6 +320,12 @@ bool recvDataCheck(void)
 	uint32_t	player;
 	uint32_t tempBuffer[DATA_MAXDATA] = {0};
 
+	if(!NetPlay.isHost)				// only host should act
+	{
+		ASSERT(false, "Host only routine detected for client!");
+		return false;
+	}
+
 	NETbeginDecode(NET_DATA_CHECK);
 	for(i = 0; i < DATA_MAXDATA; i++)
 	{
@@ -332,6 +339,13 @@ bool recvDataCheck(void)
 		debug(LOG_ERROR, "invalid player number (%u) detected.", player);
 		return false;
 	}
+
+	if (whosResponsible(player) != NetMsg.source)
+	{
+		HandleBadParam("NET_DATA_CHECK given incorrect params.", player, NetMsg.source);
+		return false;
+	}
+
 	debug(LOG_NET, "** Received NET_DATA_CHECK from player %u", player);
 	if (NetPlay.isHost)
 	{
