@@ -59,7 +59,7 @@
 // External Variables
 
 extern char	buildTime[8];
-
+extern uint8_t numDrumsNeeded;
 // ////////////////////////////////////////////////////////////////////////////
 // ////////////////////////////////////////////////////////////////////////////
 
@@ -112,6 +112,8 @@ void sendOptions()
 		NETuint8_t(&ingame.pStructureLimits[i].id);
 		NETuint8_t(&ingame.pStructureLimits[i].limit);
 	}
+	updateLimitFlags();
+	NETuint8_t(&ingame.flags);
 
 	NETend();
 }
@@ -200,6 +202,7 @@ void recvOptions()
 		NETuint8_t(&ingame.pStructureLimits[i].id);
 		NETuint8_t(&ingame.pStructureLimits[i].limit);
 	}
+	NETuint8_t(&ingame.flags);
 
 	// Do the skirmish slider settings if they are up
 	for (i = 0; i < MAX_PLAYERS; i++)
@@ -563,6 +566,7 @@ static BOOL campInit(void)
 
 	if (NetPlay.isHost)	// add oil drums
 	{
+		numDrumsNeeded = 0;
 		addOilDrum(NetPlay.playercount * 2);
 	}
 
@@ -625,6 +629,7 @@ BOOL multiGameShutdown(void)
 
 	// if we terminate the socket too quickly, then, it is possible not to get the leave message
 	SDL_Delay(1000);
+	ingame.TimeEveryoneIsInGame = 0;
 	// close game
 	NETclose();
 	NETremRedirects();
@@ -635,10 +640,12 @@ BOOL multiGameShutdown(void)
 		free(ingame.pStructureLimits);
 		ingame.pStructureLimits = NULL;
 	}
+	ingame.flags = 0;
 
 	ingame.localJoiningInProgress = false; // Clean up
 	ingame.localOptionsReceived = false;
 	ingame.bHostSetup = false;	// Dont attempt a host
+	ingame.startTime = 0;
 	NetPlay.isHost					= false;
 	bMultiPlayer					= false;	// Back to single player mode
 	bMultiMessages					= false;
