@@ -325,6 +325,12 @@ BOOL IdToDroid(UDWORD id, UDWORD player, DROID **psDroid)
 	}
 	else									// find the droid, given player
 	{
+		if (player >= MAX_PLAYERS)
+		{
+			debug(LOG_FEATURE, "Feature detected");
+			// feature hack, player = 9 are features
+			return false;
+		}
 		d = apsDroidLists[player];
 		while( (d != NULL ) && (d->id !=id))d=d->psNext;
 		if(d)
@@ -356,6 +362,12 @@ STRUCTURE *IdToStruct(UDWORD id,UDWORD player)
 	}
 	else
 	{
+		if (player >= MAX_PLAYERS)
+		{
+			debug(LOG_FEATURE, "Feature detected");
+			// feature hack, player = 9 are features
+			return NULL;
+		}
 		for(psStr=apsStructLists[player];((psStr != NULL )&&(psStr->id != id) );psStr=psStr->psNext);
 	}
 	return psStr;
@@ -381,6 +393,12 @@ FEATURE *IdToFeature(UDWORD id,UDWORD player)
 	}
 	else
 	{
+		if (player >= MAX_PLAYERS)
+		{
+			debug(LOG_FEATURE, "Feature detected");
+			// feature hack, player = 9 are features
+			return NULL;
+		}
 		for(psF=apsFeatureLists[player];((psF != NULL )&&(psF->id != id) );psF=psF->psNext);
 	}
 	return psF;
@@ -398,7 +416,7 @@ DROID_TEMPLATE *IdToTemplate(UDWORD tempId,UDWORD player)
 	if (psTempl) return psTempl;
 
 	// Check if we know which player this is from, in that case, assume it is a player template
-	if (player != ANYPLAYER)
+	if (player != ANYPLAYER && player < MAX_PLAYERS)
 	{
 		for (psTempl = apsDroidTemplates[player];			// follow templates
 		(psTempl && (psTempl->multiPlayerID != tempId ));
@@ -704,6 +722,12 @@ BOOL recvMessage(void)
 			}
 			NETend();
 
+			if (whosResponsible(player_id) != NetMsg.source && NetMsg.source != NET_HOST_ONLY)
+			{
+				HandleBadParam("NET_PLAYER_DROPPED given incorrect params.", player_id, NetMsg.source);
+				break;
+			}
+
 			debug(LOG_INFO,"** player %u has dropped!", player_id);
 
 			MultiPlayerLeave(player_id);		// get rid of their stuff
@@ -740,17 +764,25 @@ BOOL recvMessage(void)
 			recvTeamRequest();
 			break;
 		case NET_READY_REQUEST:
-			recvReadyRequest();
-
-			// if hosting try to start the game if everyone is ready
-			if(NetPlay.isHost && multiplayPlayersReady(false))
+			if (NetPlay.isHost)
 			{
-				startMultiplayerGame();
+				recvReadyRequest();
+				if (multiplayPlayersReady(false))
+				{
+					// if hosting try to start the game if everyone is ready
+					startMultiplayerGame();
+				}
 			}
 			break;
 		case NET_ARTIFACTS:
 			recvMultiPlayerRandomArtifacts();
 			break;
+		case NET_ARTIFACTS_REQUEST:
+			if (NetPlay.isHost)
+			{
+				HandleArtifact();
+			}
+			break;
 		case NET_FEATURES:
 			recvMultiPlayerFeature();
 			break;
@@ -759,22 +791,31 @@ BOOL recvMessage(void)
 			break;
 		case NET_KICK:
 		{
-			// FIX ME: in game kick ?  Is this even possible with current code?
+			// In game kick
 			uint32_t player_id;
 			char reason[MAX_KICK_REASON];
-
-			if (player_id == NET_HOST_ONLY)
-			{
-				debug(LOG_ERROR, "someone tried to kick the host--check your netplay logs!");
-				NETend();
-				break;
-			}
+			LOBBY_ERROR_TYPES KICK_TYPE = ERROR_NOERROR;
 
 			NETbeginDecode(NET_KICK);
 				NETuint32_t(&player_id);
 				NETstring( reason, MAX_KICK_REASON);
+				NETenum(&KICK_TYPE);
 			NETend();
 
+			if (NetMsg.source != NET_HOST_ONLY)
+			{
+				char buf[250]= {'\0'};
+
+				ssprintf(buf, "Player %d (%s : %s) tried to kick %u", (int) NetMsg.source, NetPlay.players[NetMsg.source].name, NetPlay.players[NetMsg.source].IPtextAddress, player_id);
+				NETlogEntry(buf, SYNC_FLAG, 0);
+				debug(LOG_ERROR, "%s", buf); 
+				if (NetPlay.isHost)
+				{
+					kickPlayer(NetMsg.source, reason, KICK_TYPE);
+				}
+				break;
+			}
+
 			if (selectedPlayer == player_id)  // we've been told to leave.
 			{
 				debug(LOG_ERROR, "You were kicked because %s", reason);
@@ -1037,7 +1078,6 @@ BOOL recvResearchStatus()
 	return true;
 }
 
-
 // ////////////////////////////////////////////////////////////////////////////
 // ////////////////////////////////////////////////////////////////////////////
 // Text Messaging between players. proceed string with players to send to.
@@ -1184,6 +1224,19 @@ BOOL sendTextMessage(const char *pStr, BOOL all)
 	return true;
 }
 
+void printConsoleNameChange(const char *oldName, const char *newName)
+{
+	char msg[MAX_CONSOLE_STRING_LENGTH];
+
+	// Player changed name.
+	sstrcpy(msg, oldName);                               // Old name.
+	sstrcat(msg, " → ");                                 // Separator
+	sstrcat(msg, newName);  // New name.
+
+	addConsoleMessage(msg, DEFAULT_JUSTIFY, selectedPlayer);  // display
+}
+
+
 //AI multiplayer message, send from a certain player index to another player index
 BOOL sendAIMessage(char *pStr, UDWORD player, UDWORD to)
 {
@@ -1303,6 +1356,11 @@ BOOL recvTextMessage()
 		NETstring(newmsg, MAX_CONSOLE_STRING_LENGTH);
 	NETend();
 
+	if (whosResponsible(playerIndex) != NetMsg.source)
+	{
+		playerIndex = NetMsg.source;  // Fix corrupted playerIndex.
+	}
+
 	if (playerIndex >= MAX_PLAYERS)
 	{
 		return false;
@@ -1350,6 +1408,11 @@ BOOL recvTextMessageAI()
 		NETstring(newmsg,MAX_CONSOLE_STRING_LENGTH);
 	NETend();
 
+	if (whosResponsible(sender) != NetMsg.source)
+	{
+		sender = NetMsg.source;  // Fix corrupted sender.
+	}
+
 	//sstrcpy(msg, getPlayerName(sender));  // name
 	//sstrcat(msg, " : ");                  // seperator
 	sstrcpy(msg, newmsg);
@@ -1576,10 +1639,10 @@ BOOL recvMapFileRequested()
 	PHYSFS_sint64 fileSize_64;
 	PHYSFS_file	*pFileHandle;
 
-	// We are not the host, so we don't care. (in fact, this would be a error)
-	if(!NetPlay.isHost)
+	if(!NetPlay.isHost)				// only host should act
 	{
-		return true;
+		ASSERT(false, "Host only routine detected for client!");
+		return false;
 	}
 
 	//	Check to see who wants the file
