@@ -61,6 +61,7 @@ typedef struct {
 	UDWORD				startTime;
 	UDWORD				numStructureLimits;					// number of limits
 	MULTISTRUCTLIMITS	*pStructureLimits;					// limits chunk.
+	uint8_t                         flags;  ///< Bitmask, shows which structures are disabled.
 	UDWORD		skScores[MAX_PLAYERS][2];			// score+kills for local skirmish players.
 	char		phrases[5][255];					// 5 favourite text messages.
 } MULTIPLAYERINGAME;
@@ -142,6 +143,7 @@ extern BOOL SendResearch		(UBYTE player,UDWORD index);
 extern BOOL SendDestroyFeature  (FEATURE *pF);					// send a destruct feature message.
 extern BOOL sendTextMessage		(const char *pStr,BOOL cast);		// send a text message
 extern BOOL sendAIMessage		(char *pStr, UDWORD player, UDWORD to);	//send AI message
+void printConsoleNameChange(const char *oldName, const char *newName);  ///< Print message to console saying a name changed.
 
 extern BOOL turnOffMultiMsg		(BOOL bDoit);
 
@@ -193,7 +195,7 @@ extern BOOL addTemplateToList(DROID_TEMPLATE *psNew, DROID_TEMPLATE **ppList);
 extern BOOL sendCheck			(void);							//send/recv  check info
 extern BOOL sendScoreCheck		(void);							//score check only(frontend)
 extern BOOL sendPing			(void);							// allow game to request pings.
-
+extern void HandleBadParam(const char *msg, const int from, const int actual);
 extern BOOL ForceDroidSync(const DROID* droidToSend);
 // multijoin
 extern BOOL sendReseachStatus	(STRUCTURE *psBuilding ,UDWORD index, UBYTE player, BOOL bStart);
