@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -83,20 +83,31 @@ static PIELIGHT flashColours[MAX_PLAYERS]=
 };
 
 static SDWORD radarWidth, radarHeight, radarCenterX, radarCenterY, radarTexWidth, radarTexHeight;
-static float RadarZoom;
+static uint8_t RadarZoom;
+static float RadarZoomMultiplier = 1.0f;
 static UDWORD radarBufferSize = 0;
+static int frameSkip = 0;
 
 static void DrawRadarTiles(void);
 static void DrawRadarObjects(void);
 static void DrawRadarExtras(float radarX, float radarY, float pixSizeH, float pixSizeV);
 static void DrawNorth(void);
 
-static void radarSize(float zoom)
+static void radarSize(int ZoomLevel)
 {
+	float zoom = (float)ZoomLevel * RadarZoomMultiplier / 16.0;
 	radarWidth = radarTexWidth * zoom;
 	radarHeight = radarTexHeight * zoom;
-	radarCenterX = pie_GetVideoBufferWidth() - BASE_GAP * 4 - MAX(radarHeight, radarWidth)/2;
-	radarCenterY = pie_GetVideoBufferHeight() - BASE_GAP * 4 - MAX(radarWidth, radarHeight)/2;
+	if (rotateRadar)
+	{
+		radarCenterX = pie_GetVideoBufferWidth() - BASE_GAP * 4 - MAX(radarHeight, radarWidth) / 2;
+		radarCenterY = pie_GetVideoBufferHeight() - BASE_GAP * 4 - MAX(radarWidth, radarHeight) / 2;
+	}
+	else
+	{
+		radarCenterX = pie_GetVideoBufferWidth() - BASE_GAP * 4 - radarWidth / 2;
+		radarCenterY = pie_GetVideoBufferHeight() - BASE_GAP * 4 - radarHeight / 2;
+	}
 	debug(LOG_WZ, "radar=(%u,%u) tex=(%u,%u) size=(%u,%u)", radarCenterX, radarCenterY, radarTexWidth, radarTexHeight, radarWidth, radarHeight);
 }
 
@@ -104,8 +115,8 @@ void radarInitVars(void)
 {
 	radarTexWidth = 0;
 	radarTexHeight = 0;
-	RadarZoom = 1.0f;
-	debug(LOG_WZ, "Resetting radar zoom to %f", RadarZoom);
+	RadarZoom = DEFAULT_RADARZOOM;
+	debug(LOG_WZ, "Resetting radar zoom to %u", RadarZoom);
 	radarSize(RadarZoom);
 }
 
@@ -140,13 +151,20 @@ BOOL resizeRadar(void)
 	radarBuffer = malloc(radarBufferSize);
 	if (radarBuffer == NULL)
 	{
-		debug(LOG_ERROR, "Out of memory!");
+		debug(LOG_FATAL, "Out of memory!");
 		abort();
 		return false;
 	}
 	memset(radarBuffer, 0, radarBufferSize);
-	RadarZoom = (float)MAX(RADWIDTH, RADHEIGHT) / (float)MAX(radarTexWidth, radarTexHeight);
-	debug(LOG_WZ, "Setting radar zoom to %f", RadarZoom);
+        if (rotateRadar)
+	{
+		RadarZoomMultiplier = (float)MAX(RADWIDTH, RADHEIGHT) / (float)MAX(radarTexWidth, radarTexHeight);
+	}
+	else
+	{
+		RadarZoomMultiplier = 1.0f;
+	}
+	debug(LOG_WZ, "Setting radar zoom to %u", RadarZoom);
 	radarSize(RadarZoom);
 
 	return true;
@@ -162,17 +180,27 @@ BOOL ShutdownRadar(void)
 	return true;
 }
 
-void SetRadarZoom(float ZoomLevel)
+void SetRadarZoom(uint8_t ZoomLevel)
 {
-	if (ZoomLevel <= MAX_RADARZOOM && ZoomLevel >= MIN_RADARZOOM)
+	if (ZoomLevel < 4) // old savegame format didn't save zoom levels very well
 	{
-		debug(LOG_WZ, "Setting radar zoom to %f from %f", ZoomLevel, RadarZoom);
-		RadarZoom = ZoomLevel;
-		radarSize(ZoomLevel);
+		ZoomLevel = DEFAULT_RADARZOOM;
 	}
+	if (ZoomLevel > MAX_RADARZOOM)
+	{
+		ZoomLevel = MAX_RADARZOOM;
+	}
+	if (ZoomLevel < MIN_RADARZOOM)
+	{
+		ZoomLevel = MIN_RADARZOOM;
+	}
+	debug(LOG_WZ, "Setting radar zoom to %u from %u", ZoomLevel, RadarZoom);
+	RadarZoom = ZoomLevel;
+	radarSize(RadarZoom);
+	frameSkip = 0;
 }
 
-float GetRadarZoom(void)
+uint8_t GetRadarZoom(void)
 {
 	return RadarZoom;
 }
@@ -200,13 +228,6 @@ void CalcRadarPosition(int mX, int mY, int *PosX, int *PosY)
 	pos.x += radarWidth/2.0;
 	pos.y += radarHeight/2.0;
 
-	if (pos.x<0 || pos.y<0 || pos.x>=radarWidth || pos.y>=radarHeight)
-	{
-		ASSERT(false, "clicked outside radar minimap (%d, %d) -> (%.1f,%.1f)", mX, mY, pos.x, pos.y);
-		*PosX = 0;
-		*PosY = 0;
-		return;
-	}
 	CalcRadarPixelSize(&pixSizeH, &pixSizeV);
 	sPosX = pos.x / pixSizeH;	// adjust for pixel size
 	sPosY = pos.y / pixSizeV;
@@ -243,7 +264,6 @@ void CalcRadarPosition(int mX, int mY, int *PosX, int *PosY)
 void drawRadar(void)
 {
 	float	pixSizeH, pixSizeV;
-	static int frameSkip = 0;
 
 	ASSERT(radarBuffer, "No radar buffer allocated");
 	if (!radarBuffer)
@@ -255,9 +275,14 @@ void drawRadar(void)
 
 	if (frameSkip <= 0)
 	{
+		bool filter = true;
+		if (!rotateRadar)
+		{
+			filter = RadarZoom % 16 != 0;
+		}
 		DrawRadarTiles();
 		DrawRadarObjects();
-		pie_DownLoadRadar(radarBuffer, radarTexWidth, radarTexHeight);
+		pie_DownLoadRadar(radarBuffer, radarTexWidth, radarTexHeight, filter);
 		frameSkip = RADAR_FRAME_SKIP;
 	}
 	frameSkip--;
@@ -271,21 +296,22 @@ void drawRadar(void)
 			DrawNorth();
 		}
 		// draw the box at the dimensions of the map
-		iV_TransBoxFill(-radarWidth/2.0,
-						-radarHeight/2.0,
+		iV_TransBoxFill(-radarWidth/2.0 - 1,
+						-radarHeight/2.0 - 1,
 						 radarWidth/2.0,
 						 radarHeight/2.0);
-		pie_RenderRadar(-radarWidth/2.0,
-						-radarHeight/2.0,
+		pie_RenderRadar(-radarWidth/2.0 - 1,
+						-radarHeight/2.0 - 1,
 						 radarWidth,
 						 radarHeight);
         pie_MatBegin();
             pie_TRANSLATE(-radarWidth/2 - 1, -radarHeight/2 - 1, 0);
             DrawRadarExtras(0, 0, pixSizeH, pixSizeV);
         pie_MatEnd();
-		drawRadarBlips(-radarWidth/2.0, -radarHeight/2.0, pixSizeH, pixSizeV);
+		drawRadarBlips(-radarWidth/2.0 - 1, -radarHeight/2.0 - 1, pixSizeH, pixSizeV);
 	pie_MatEnd();
 }
+
 static void DrawNorth(void)
 {
 	iV_DrawImage(IntImages, RADAR_NORTH, -((radarWidth / 2.0) + (IntImages->ImageDefs[RADAR_NORTH].Width) + 1) , -(radarHeight / 2.0));
@@ -295,9 +321,16 @@ static PIELIGHT appliedRadarColour(RADAR_DRAW_MODE radarDrawMode, MAPTILE *WTile
 {
 	PIELIGHT WScr = WZCOL_BLACK;	// squelch warning
 
+	// draw radar terrain on/off feature
+	if ((getRevealStatus() || radarDrawMode == RADAR_MODE_TERRAIN_SEEN) && !TEST_TILE_VISIBLE(selectedPlayer, WTile))
+	{
+		return WZCOL_RADAR_BACKGROUND;
+	}
+
 	switch(radarDrawMode)
 	{
 		case RADAR_MODE_TERRAIN:
+		case RADAR_MODE_TERRAIN_SEEN:
 		{
 			// draw radar terrain on/off feature
 			PIELIGHT col = tileColours[TileNumber_tile(WTile->texture)];
@@ -305,6 +338,18 @@ static PIELIGHT appliedRadarColour(RADAR_DRAW_MODE radarDrawMode, MAPTILE *WTile
 			col.byte.r = sqrtf(col.byte.r * WTile->illumination);
 			col.byte.b = sqrtf(col.byte.b * WTile->illumination);
 			col.byte.g = sqrtf(col.byte.g * WTile->illumination);
+			if (terrainType(WTile) == TER_CLIFFFACE)
+			{
+				col.byte.r /= 2;
+				col.byte.b /= 2;
+				col.byte.g /= 2;
+			}
+			if (!hasSensorOnTile(WTile, selectedPlayer))
+			{
+				col.byte.r /= 2;
+				col.byte.b /= 2;
+				col.byte.g /= 2;
+			}
 			WScr = col;
 		}
 		break;
@@ -316,12 +361,23 @@ static PIELIGHT appliedRadarColour(RADAR_DRAW_MODE radarDrawMode, MAPTILE *WTile
 			col.byte.r = sqrtf(col.byte.r * (WTile->illumination + WTile->height) / 2);
 			col.byte.b = sqrtf(col.byte.b * (WTile->illumination + WTile->height) / 2);
 			col.byte.g = sqrtf(col.byte.g * (WTile->illumination + WTile->height) / 2);
+			if (terrainType(WTile) == TER_CLIFFFACE)
+			{
+				col.byte.r /= 2;
+				col.byte.b /= 2;
+				col.byte.g /= 2;
+			}
+			if (!hasSensorOnTile(WTile, selectedPlayer))
+			{
+				col.byte.r /= 2;
+				col.byte.b /= 2;
+				col.byte.g /= 2;
+			}
 			WScr = col;
 		}
 		break;
 		case RADAR_MODE_HEIGHT_MAP:
 		{
-			// draw radar terrain on/off feature
 			WScr.byte.r = WScr.byte.g = WScr.byte.b = WTile->height;
 		}
 		break;
@@ -352,12 +408,7 @@ static void DrawRadarTiles(void)
 			size_t pos = radarTexWidth * (y - scrollMinY) + (x - scrollMinX);
 
 			ASSERT(pos * sizeof(*radarBuffer) < radarBufferSize, "Buffer overrun");
-			if (!getRevealStatus() || TEST_TILE_VISIBLE(selectedPlayer, psTile))
-			{
-				radarBuffer[pos] = appliedRadarColour(radarDrawMode, psTile).rgba;
-			} else {
-				radarBuffer[pos] = WZCOL_RADAR_BACKGROUND.rgba;
-			}
+			radarBuffer[pos] = appliedRadarColour(radarDrawMode, psTile).rgba;
 		}
 	}
 }
@@ -605,8 +656,8 @@ BOOL CoordInRadar(int x,int y)
 	{
 		pos = Vector2f_Rotate2f(pos, -player.r.y/DEG(1));
 	}
-	pos.x += radarWidth/2;
-	pos.y += radarHeight/2;
+	pos.x += radarWidth/2.0;
+	pos.y += radarHeight/2.0;
 
 	if (pos.x<0 || pos.y<0 || pos.x>=radarWidth || pos.y>=radarHeight)
 	{
