@@ -1636,7 +1636,7 @@ BOOL scrSkDoResearch(void)
 	PLAYER_RESEARCH		*pPlayerRes;
 	RESEARCH			*pResearch;
 
-	if (!stackPopParams(3,ST_STRUCTURE, &psBuilding, VAL_INT, &player, VAL_INT,&bias ))
+	if (!stackPopParams(3, ST_STRUCTURE, &psBuilding, VAL_INT, &player, VAL_INT, &bias))
 	{
 		return false;
 	}
@@ -1650,7 +1650,7 @@ BOOL scrSkDoResearch(void)
 	}
 
 	// choose a topic to complete.
-	for(i=0;i<numResearch;i++)
+	for(i=0; i < numResearch; i++)
 	{
 		if (skTopicAvail(i, player) && (!bMultiPlayer || !beingResearchedByAlly(i, player)))
 		{
@@ -1660,19 +1660,20 @@ BOOL scrSkDoResearch(void)
 
 	if(i != numResearch)
 	{
-		pResearch = (asResearch+i);
-		pPlayerRes				= asPlayerResList[player]+ i;
-		psResFacilty->psSubject = (BASE_STATS*)pResearch;		  //set the subject up
+		pResearch = (asResearch + i);
+		pPlayerRes = asPlayerResList[player] + i;
+		psResFacilty->psSubject = (BASE_STATS*)pResearch;			//set the subject up
 
 		if (IsResearchCancelled(pPlayerRes))
 		{
-			psResFacilty->powerAccrued = pResearch->researchPower;//set up as if all power available for cancelled topics
+			psResFacilty->powerAccrued = pResearch->researchPower;	//set up as if all power available for cancelled topics
 		}
 		else
 		{
 			psResFacilty->powerAccrued = 0;
 		}
 
+		sendReseachStatus(psBuilding, i, player, true);			// inform others, I'm researching this.
 		MakeResearchStarted(pPlayerRes);
 		psResFacilty->timeStarted = ACTION_START_TIME;
 		psResFacilty->timeStartHold = 0;
@@ -1683,8 +1684,8 @@ BOOL scrSkDoResearch(void)
 		}
 #if defined (DEBUG)
 		{
-			char				sTemp[128];
-			sprintf(sTemp,"player:%d starts topic: %s",player, asResearch[i].pName );
+			char	sTemp[128];
+			sprintf(sTemp,"[debug]player:%d starts topic: %s",player, asResearch[i].pName );
 			NETlogEntry(sTemp, SYNC_FLAG, 0);
 		}
 #endif
@@ -1820,7 +1821,7 @@ static BOOL defenseLocation(BOOL variantB)
 	UDWORD		x,y,gX,gY,dist,player,nearestSoFar,count;
 	GATEWAY		*psGate,*psChosenGate;
 	DROID		*psDroid;
-	BASE_STATS	*psStats,*psWStats;
+	BASE_STATS	*psWStats;
 	UDWORD		x1,x2,x3,x4,y1,y2,y3,y4;
 	BOOL		noWater;
 	UDWORD      minCount;
@@ -1845,7 +1846,6 @@ static BOOL defenseLocation(BOOL variantB)
 	}
 
 	ASSERT_OR_RETURN( false, statIndex < numStructureStats, "Invalid range referenced for numStructureStats, %d > %d", statIndex, numStructureStats);
-	psStats = (BASE_STATS *)(asStructureStats + statIndex);
 
 	ASSERT_OR_RETURN( false, statIndex2 < numStructureStats, "Invalid range referenced for numStructureStats, %d > %d", statIndex2, numStructureStats);
 	psWStats = (BASE_STATS *)(asStructureStats + statIndex2);
