@@ -163,11 +163,12 @@ void statsInitVars(void)
 	numSpecialAbility = 0;
 
 	//initialise the upgrade structures
-	memset(asWeaponUpgrade, 0, MAX_PLAYERS * WSC_NUM_WEAPON_SUBCLASSES * sizeof(WEAPON_UPGRADE));
-	memset(asSensorUpgrade, 0, MAX_PLAYERS * sizeof(SENSOR_UPGRADE));
-	memset(asECMUpgrade, 0, MAX_PLAYERS * sizeof(ECM_UPGRADE));
-	memset(asRepairUpgrade, 0, MAX_PLAYERS * sizeof(REPAIR_UPGRADE));
-	memset(asBodyUpgrade, 0, MAX_PLAYERS * sizeof(BODY_UPGRADE) * BODY_TYPE);
+	memset(asWeaponUpgrade, 0, sizeof(asWeaponUpgrade));
+	memset(asSensorUpgrade, 0, sizeof(asSensorUpgrade));
+	memset(asECMUpgrade, 0, sizeof(asECMUpgrade));
+	memset(asRepairUpgrade, 0, sizeof(asRepairUpgrade));
+	memset(asConstUpgrade, 0, sizeof(asConstUpgrade));
+	memset(asBodyUpgrade, 0, sizeof(asBodyUpgrade));
 
 	// init the max values
 	maxComponentWeight = maxBodyArmour = maxBodyPower =
@@ -328,9 +329,9 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 					hitGfx[MAX_STR_LENGTH], missGfx[MAX_STR_LENGTH],
 					waterGfx[MAX_STR_LENGTH], muzzleGfx[MAX_STR_LENGTH],
 					trailGfx[MAX_STR_LENGTH], dummy[MAX_STR_LENGTH];
-	char			fireOnMove[10], weaponClass[15], weaponSubClass[15],
-					weaponEffect[16], movement[15], facePlayer[5],		//weaponEffect[15] caused stack corruption. --Qamly
-					faceInFlight[5],lightWorld[5];
+	char			fireOnMove[MAX_STR_LENGTH], weaponClass[MAX_STR_LENGTH], weaponSubClass[MAX_STR_LENGTH],
+					weaponEffect[MAX_STR_LENGTH], movement[MAX_STR_LENGTH], facePlayer[MAX_STR_LENGTH],  //weaponEffect[15] caused stack corruption. --Qamly
+					faceInFlight[MAX_STR_LENGTH],lightWorld[MAX_STR_LENGTH];
 	UDWORD			longRange, effectSize, numAttackRuns, designable;
 	UDWORD			numRounds;
 
@@ -373,24 +374,24 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 
 
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pWeaponData,"%[^','],%[^','],%d,%d,%d,%d,%d,%d,%[^','],\
-			%[^','],%[^','],%[^','],%[^','],%[^','],%[^','],%[^','],%d,\
-			%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%[^','],\
-			%[^','],%[^','],%[^','],%[^','],%d,%d,%d,%[^','],%[^','],%d,%d,\
-			%[^','],%d,%d,%d,%d,%d",
-			(char *)&WeaponName, (char *)&dummy, &psStats->buildPower,&psStats->buildPoints,
+		sscanf(pWeaponData,"%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%d,%255[^,'\r\n],\
+			%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%d,\
+			%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%255[^,'\r\n],\
+			%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%255[^,'\r\n],%255[^,'\r\n],%d,%d,\
+			%255[^,'\r\n],%d,%d,%d,%d,%d",
+			WeaponName, dummy, &psStats->buildPower,&psStats->buildPoints,
 			&psStats->weight, &dummyVal, &dummyVal,
-			&psStats->body, (char *)&GfxFile, (char *)&mountGfx, (char *)&muzzleGfx, (char *)&flightGfx,
-			(char *)&hitGfx, (char *)&missGfx, (char *)&waterGfx, (char *)&trailGfx, &psStats->shortRange,
+			&psStats->body, GfxFile, mountGfx, muzzleGfx, flightGfx,
+			hitGfx, missGfx, waterGfx, trailGfx, &psStats->shortRange,
 			&psStats->longRange,&psStats->shortHit, &psStats->longHit,
 			&psStats->firePause, &psStats->numExplosions, &numRounds,
 			&psStats->reloadTime, &psStats->damage, &psStats->radius,
 			&psStats->radiusHit, &psStats->radiusDamage, &psStats->incenTime,
 			&psStats->incenDamage, &psStats->incenRadius, &psStats->directLife,
 			&psStats->radiusLife, &psStats->flightSpeed, &psStats->indirectHeight,
-			(char *)&fireOnMove, (char *)&weaponClass, (char *)&weaponSubClass, (char *)&movement, (char *)&weaponEffect,
-			&rotate, &maxElevation, &minElevation, (char *)&facePlayer, (char *)&faceInFlight,
-			&psStats->recoilValue, &psStats->minRange,	(char *)&lightWorld,
+			fireOnMove, weaponClass, weaponSubClass, movement, weaponEffect,
+			&rotate, &maxElevation, &minElevation, facePlayer, faceInFlight,
+			&psStats->recoilValue, &psStats->minRange, lightWorld,
 			&effectSize, &surfaceToAir, &numAttackRuns, &designable, &penetrate);
 
 			psStats->numRounds = (UBYTE)numRounds;
@@ -770,11 +771,11 @@ BOOL loadBodyStats(const char *pBodyData, UDWORD bufferSize)
 
 		//Watermelon:added 10 %d to store FRONT,REAR,LEFT,RIGHT,TOP,BOTTOM armour values
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pBodyData,"%[^','],%[^','],%[^','],%d,%d,%d,%d,%[^','],\
+		sscanf(pBodyData,"%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%255[^,'\r\n],\
 			%d,%d,%d, \
-			%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%[^','],%d",
-			(char*)&BodyName, (char*)&dummy, (char*)&size, &psStats->buildPower,&psStats->buildPoints,
-			&psStats->weight, &psStats->body, (char*)&GfxFile, &dummyVal,
+			%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%255[^,'\r\n],%d",
+			BodyName, dummy, size, &psStats->buildPower,&psStats->buildPoints,
+			&psStats->weight, &psStats->body, GfxFile, &dummyVal,
 			&psStats->weaponSlots, &psStats->powerOutput,
 			(int*)&psStats->armourValue[HIT_SIDE_FRONT][WC_KINETIC], (int*)&psStats->armourValue[HIT_SIDE_FRONT][WC_HEAT],
 			(int*)&psStats->armourValue[HIT_SIDE_REAR][WC_KINETIC],  (int*)&psStats->armourValue[HIT_SIDE_REAR][WC_HEAT],
@@ -782,7 +783,7 @@ BOOL loadBodyStats(const char *pBodyData, UDWORD bufferSize)
 			(int*)&psStats->armourValue[HIT_SIDE_RIGHT][WC_KINETIC], (int*)&psStats->armourValue[HIT_SIDE_RIGHT][WC_HEAT],
 			(int*)&psStats->armourValue[HIT_SIDE_TOP][WC_KINETIC],   (int*)&psStats->armourValue[HIT_SIDE_TOP][WC_HEAT],
 			(int*)&psStats->armourValue[HIT_SIDE_BOTTOM][WC_KINETIC],(int*)&psStats->armourValue[HIT_SIDE_BOTTOM][WC_HEAT],
-			(char*)&flameIMD, &designable);//, &psStats->armourValue[WC_EXPLOSIVE],
+			flameIMD, &designable);//, &psStats->armourValue[WC_EXPLOSIVE],
 			//&psStats->armourValue[WC_MISC]);
 
 		//allocate storage for the name
@@ -878,10 +879,10 @@ BOOL loadBrainStats(const char *pBrainData, UDWORD bufferSize)
 		BrainName[0] = '\0';
 		weaponName[0] = '\0';
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pBrainData,"%[^','],%[^','],%d,%d,%d,%d,%d,%[^','],%d",
-			(char*)&BrainName, (char*)&dummy, &psStats->buildPower,&psStats->buildPoints,
+		sscanf(pBrainData,"%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%255[^,'\r\n],%d",
+			BrainName, dummy, &psStats->buildPower,&psStats->buildPoints,
 			&psStats->weight, &dummyVal, &dummyVal,
-			(char*)&weaponName, &psStats->progCap); //, &psStats->AICap, &psStats->AISpeed);
+			weaponName, &psStats->progCap);
 
 		if (!allocateStatName((BASE_STATS *)psStats, BrainName))
 		{
@@ -1004,11 +1005,11 @@ BOOL loadPropulsionStats(const char *pPropulsionData, UDWORD bufferSize)
 		imdName[0] = '\0';
 
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pPropulsionData,"%[^','],%[^','],%d,%d,%d,%d,%d,%d,%[^','],\
-			%[^','],%d,%d",
-			(char*)&PropulsionName, (char*)&dummy, &psStats->buildPower,&psStats->buildPoints,
+		sscanf(pPropulsionData,"%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%d,%255[^,'\r\n],\
+			%255[^,'\r\n],%d,%d",
+			PropulsionName, dummy, &psStats->buildPower,&psStats->buildPoints,
 			&psStats->weight, &dummyVal, &dummyVal,
-			&psStats->body,	(char*)&imdName, (char*)&type, &psStats->maxSpeed, &designable);
+			&psStats->body, imdName, type, &psStats->maxSpeed, &designable);
 
 		if (!allocateStatName((BASE_STATS *)psStats, PropulsionName))
 		{
@@ -1119,12 +1120,12 @@ BOOL loadSensorStats(const char *pSensorData, UDWORD bufferSize)
 		location[0] = '\0';
 		type[0] = '\0';
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pSensorData,"%[^','],%[^','],%d,%d,%d,%d,%d,%d,%[^','],\
-			%[^','],%d,%[^','],%[^','],%d,%d,%d",
-			(char*)&SensorName, (char*)&dummy, &psStats->buildPower,&psStats->buildPoints,
+		sscanf(pSensorData,"%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%d,%255[^,'\r\n],\
+			%255[^,'\r\n],%d,%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d",
+			SensorName, dummy, &psStats->buildPower,&psStats->buildPoints,
 			&psStats->weight, &dummyVal, &dummyVal,
-			&psStats->body,	(char*)&GfxFile,(char*)&mountGfx,
-			&psStats->range, (char*)&location, (char*)&type, &psStats->time, &psStats->power, &designable);
+			&psStats->body, GfxFile, mountGfx,
+			&psStats->range, location, type, &psStats->time, &psStats->power, &designable);
 
 		if (!allocateStatName((BASE_STATS *)psStats, SensorName))
 		{
@@ -1254,11 +1255,11 @@ BOOL loadECMStats(const char *pECMData, UDWORD bufferSize)
 		mountGfx[0] = '\0';
 		location[0] = '\0';
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pECMData,"%[^','],%[^','],%d,%d,%d,%d,%d,%d,%[^','],%[^','],\
-			%[^','],%d,%d,%d",
-			(char*)&ECMName, (char*)&dummy, &psStats->buildPower,&psStats->buildPoints,
+		sscanf(pECMData,"%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%d,%255[^,'\r\n],%255[^,'\r\n],\
+			%255[^,'\r\n],%d,%d,%d",
+			ECMName, dummy, &psStats->buildPower,&psStats->buildPoints,
 			&psStats->weight, &dummyVal, &dummyVal,
-			&psStats->body,	(char*)&GfxFile, (char*)&mountGfx, (char*)&location, &psStats->power,
+			&psStats->body, GfxFile, mountGfx, location, &psStats->power,
 			&psStats->range, &designable);
 
 		// set a default ECM range for now
@@ -1363,11 +1364,11 @@ BOOL loadRepairStats(const char *pRepairData, UDWORD bufferSize)
 		location[0] = '\0';
 
 	//read the data into the storage - the data is delimeted using comma's
-		sscanf(pRepairData,"%[^','],%[^','],%d,%d,%d,%d,%d,%d,%[^','],\
-			%[^','],%[^','],%d,%d,%d",
-			(char*)&RepairName, (char*)&dummy, &psStats->buildPower,&psStats->buildPoints,
+		sscanf(pRepairData,"%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%d,%255[^,'\r\n],\
+			%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d",
+			RepairName, dummy, &psStats->buildPower,&psStats->buildPoints,
 			&psStats->weight, &dummyVal, &dummyVal,
-			&repairArmour, (char*)&location, (char*)&GfxFile, (char*)&mountGfx,
+			&repairArmour, location, GfxFile, mountGfx,
 			&psStats->repairPoints, &psStats->time,&designable);
 
 		if (!allocateStatName((BASE_STATS *)psStats, RepairName))
@@ -1481,11 +1482,11 @@ BOOL loadConstructStats(const char *pConstructData, UDWORD bufferSize)
 		GfxFile[0] = '\0';
 		mountGfx[0] = '\0';
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pConstructData,"%[^','],%[^','],%d,%d,%d,%d,%d,%d,%[^','],\
-			%[^','],%d,%d",
-			(char*)&ConstructName, (char*)&dummy, &psStats->buildPower,&psStats->buildPoints,
+		sscanf(pConstructData,"%255[^,'\r\n],%255[^,'\r\n],%d,%d,%d,%d,%d,%d,%255[^,'\r\n],\
+			%255[^,'\r\n],%d,%d",
+			ConstructName, dummy, &psStats->buildPower,&psStats->buildPoints,
 			&psStats->weight, &dummyVal, &dummyVal,
-			&psStats->body, (char*)&GfxFile, (char*)&mountGfx,
+			&psStats->body, GfxFile, mountGfx,
 			&psStats->constructPoints,&designable);
 
 		if (!allocateStatName((BASE_STATS *)psStats, ConstructName))
@@ -1578,8 +1579,8 @@ BOOL loadPropulsionTypes(const char *pPropTypeData, UDWORD bufferSize)
 	for (i=0; i < NumTypes; i++)
 	{
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pPropTypeData,"%[^','],%[^','],%d",
-			(char*)&PropulsionName, (char*)&flightName, &multiplier);
+		sscanf(pPropTypeData,"%255[^,'\r\n],%255[^,'\r\n],%d",
+			PropulsionName, flightName, &multiplier);
 
 		//set the pointer for this record based on the name
 		if (!getPropulsionType(PropulsionName, &type))
@@ -1717,7 +1718,7 @@ BOOL loadSpecialAbility(const char *pSAbilityData, UDWORD bufferSize)
 	for (i=0; i < NumTypes; i++)
 	{
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pSAbilityData,"%[^','],%d",(char*)&SAbilityName, &accessID);
+		sscanf(pSAbilityData,"%255[^,'\r\n],%d", SAbilityName, &accessID);
 		//check that the data is ordered in the way it will be stored
 		if (accessID != i)
 		{
@@ -1788,8 +1789,8 @@ BOOL loadBodyPropulsionIMDs(const char *pData, UDWORD bufferSize)
 
 		/*read the data into the storage - the data is delimited using comma's
 		not interested in the last number - needed for sscanf*/
-		sscanf(pData,"%[^','],%[^','],%[^','],%[^','],%*d",(char*)&bodyName,
-            (char*)&propulsionName, (char*)&leftIMD, (char*)&rightIMD);
+		sscanf(pData,"%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%*d", bodyName,
+		       propulsionName, leftIMD, rightIMD);
 
 		//get the body stats
 		found = false;
@@ -1922,7 +1923,7 @@ BOOL loadWeaponSounds(const char *pSoundData, UDWORD bufferSize)
 		szWeaponWav[0]    = '\0';
 		szExplosionWav[0] = '\0';
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pSoundData,"%[^','],%[^','],%[^','],%d",
+		sscanf(pSoundData,"%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%d",
 			WeaponName, szWeaponWav, szExplosionWav, &iDum);
 
 		if ( statsGetAudioIDFromString( WeaponName, szWeaponWav, &weaponSoundID ) == false )
@@ -1974,8 +1975,8 @@ BOOL loadWeaponModifiers(const char *pWeapModData, UDWORD bufferSize)
 	for (i=0; i < NumRecords; i++)
 	{
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pWeapModData,"%[^','],%[^','],%d",
-			(char*)&weaponEffectName, (char*)&propulsionName, &modifier);
+		sscanf(pWeapModData,"%255[^,'\r\n],%255[^,'\r\n],%d",
+			weaponEffectName, propulsionName, &modifier);
 
 		//get the weapon effect inc
 		if (!getWeaponEffect(weaponEffectName, &effectInc))
@@ -2030,7 +2031,7 @@ BOOL loadPropulsionSounds(const char *pPropSoundData, UDWORD bufferSize)
 
 		propulsionName[0] = '\0';
 		//read the data into the storage - the data is delimeted using comma's
-		sscanf(pPropSoundData,"%[^','],%[^','],%[^','],%[^','],%[^','],%[^','],%[^','],%d",
+		sscanf(pPropSoundData,"%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%255[^,'\r\n],%d",
 			propulsionName, szStart, szIdle, szMoveOff, szMove, szHiss, szShutDown, &iDum);
 
 		if ( statsGetAudioIDFromString( propulsionName, szStart, &startID ) == false )
@@ -3342,7 +3343,7 @@ SENSOR_STATS *objActiveRadar(BASE_OBJECT *psObj)
 		break;
 	case OBJ_STRUCTURE:
 		psStats = ((STRUCTURE *)psObj)->pStructureType->pSensor;
-		if (psStats == NULL || psStats->location != LOC_TURRET)
+		if (psStats == NULL || psStats->location != LOC_TURRET || ((STRUCTURE *)psObj)->status != SS_BUILT)
 		{
 			return NULL;
 		}
@@ -3359,7 +3360,7 @@ bool objRadarDetector(BASE_OBJECT *psObj)
 	{
 		STRUCTURE *psStruct = (STRUCTURE *)psObj;
 
-		return (psStruct->pStructureType->pSensor && psStruct->pStructureType->pSensor->type == RADAR_DETECTOR_SENSOR);
+		return (psStruct->status == SS_BUILT && psStruct->pStructureType->pSensor && psStruct->pStructureType->pSensor->type == RADAR_DETECTOR_SENSOR);
 	}
 	else if (psObj->type == OBJ_DROID)
 	{
